==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ToolActionCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionCheckboxDescription } from "./ToolActionCheckboxDescription";
/**
 * @hidden
 */
export let ToolActionCheckboxDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionCheckboxDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionCheckboxDescriptionMetadata.a == null) {
                ToolActionCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionCheckboxDescriptionMetadata.c(ToolActionCheckboxDescriptionMetadata.a);
            }
            if (a.j(ToolActionCheckboxDescriptionMetadata.a)) {
                return;
            }
            a.y(ToolActionCheckboxDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionCheckboxDescriptionMetadata.b(a);
            a.aa("ToolActionCheckbox", () => new ToolActionCheckboxDescription());
            a.z("ToolActionCheckbox", ToolActionCheckboxDescriptionMetadata.a);
        }
    }
    ToolActionCheckboxDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionCheckboxDescriptionMetadata, 'ToolActionCheckboxDescriptionMetadata');
    ToolActionCheckboxDescriptionMetadata.a = null;
    return ToolActionCheckboxDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ToolActionCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionCheckboxDescription } from "./ToolActionCheckboxDescription";
/**
 * @hidden
 */
export let ToolActionCheckboxDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionCheckboxDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionCheckboxDescriptionMetadata.a == null) {
                ToolActionCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionCheckboxDescriptionMetadata.c(ToolActionCheckboxDescriptionMetadata.a);
            }
            if (a.k(ToolActionCheckboxDescriptionMetadata.a)) {
                return;
            }
            a.aa(ToolActionCheckboxDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionCheckboxDescriptionMetadata.b(a);
            a.ac("ToolActionCheckbox", () => new ToolActionCheckboxDescription());
            a.ab("ToolActionCheckbox", ToolActionCheckboxDescriptionMetadata.a);
        }
    }
    ToolActionCheckboxDescriptionMetadata.$t = /*@__PURE__*/ markType(ToolActionCheckboxDescriptionMetadata, 'ToolActionCheckboxDescriptionMetadata');
    ToolActionCheckboxDescriptionMetadata.a = null;
    return ToolActionCheckboxDescriptionMetadata;
})();
